@@ -2,6 +2,7 @@ package App::FatPacker;
 
 use strict;
 use warnings FATAL => 'all';
+use 5.008001;
 use Getopt::Long;
 use Cwd qw(cwd);
 use File::Find qw(find);
@@ -13,7 +14,7 @@ use File::Copy qw(copy);
 use File::Path qw(mkpath rmtree);
 use B qw(perlstring);
 
-our $VERSION = '0.009012'; # 0.9.012
+our $VERSION = '0.009013'; # 0.9.013
 
 $VERSION = eval $VERSION;
 
@@ -212,7 +213,7 @@ sub script_command_file {
         if ($] < 5.008) {
           return sub {
             return 0 unless length $fat;
-            $text =~ s/^([^\n]*\n?)//;
+            $fat =~ s/^([^\n]*\n?)//;
             $_ = $1;
             return 1;
           };
